"use strict";
this.name			= "Tionisla Chronicle Array OXP";
this.author			= "Storm";
this.copyright		= "Creative Commons Attribution - Non-Commercial - Share Alike 3.0 license";
this.description	= "Addition of a Broadcast Array station to each galactic chart";

// Arrays for the Broadcast Arrays locations by planet, their shipdata.plist names, and 'channel' name 
this.broadcastArrayPlanet = [124, 103, 197, 58, 211, 225, 184, 206];
this.broadcastArrayName = ["Tionisla Chronicle", "Views of the Worlds", "GNN", "Daily Wail", "G5TVN", "Rooters", "StarSports", "Snoopers"];
this.broadcastChannel = ["tca", "votw", "gnn", "dailywail", "g5tvn", "rooters", "starsports", "snoopers"];
this._debug = false;

this.systemWillPopulate = function() {
	// Check if in a system where a Broadcast Array is based, and add if so...
	if(system.ID == this.broadcastArrayPlanet[galaxyNumber] || this._debug === true) {
		if(system.countShipsWithRole("broadcast_array") == 0) {
			// Work out the location for placement of the Broadcast Array and it's beacon...
			var vector = system.mainPlanet.position.subtract(system.sun.position).direction();
			var arraypos = system.mainPlanet.position.add(vector.multiply(system.mainPlanet.radius * 4));

			system.setPopulator("tca", {
				priority: 200,
				location: "COORDINATES",
				groupCount: 1,
				callback: function(pos) {
					var tca = worldScripts["Tionisla Chronicle Array OXP"];
					// Add Broadcast Array to system...
					var broadcastArray = system.addShips("broadcast_array", 1, pos, 0)[0];
					broadcastArray.orientation = system.mainPlanet.position.subtract(broadcastArray.position).direction().rotationTo([0, 0, 1]);
					broadcastArray.scannerDisplayColor1 = "25 100 175";
					broadcastArray.scannerDisplayColor2 = "50 150 255";

					var vect = system.mainPlanet.position.subtract(system.sun.position).direction();
							
					// Add the Broadcast Array's Beacon to system...
					var buoyPos = system.mainPlanet.position.add(vect.multiply((system.mainPlanet.radius * 4) - 10000));
					var navbuoy = system.addShips("broadcast_array_beacon", 1, buoyPos, 0)[0];
					navbuoy.orientation = system.mainPlanet.position.subtract(broadcastArray.position).direction().rotationTo([0,0,1]);
					// Change the Broadcast Array's docking display / beacon to match the appropriate 'channel'...
					broadcastArray.displayName = (tca.broadcastArrayName[galaxyNumber] + " Array");
					broadcastArray.beaconLabel = (tca.broadcastArrayName[galaxyNumber] + " Array");
					var broadcastDisplayEmissionPng = (tca.broadcastChannel[galaxyNumber] + "_display_emission_map.png");
					broadcastArray.subEntities[4].setMaterials(
						{"broadcast_array_display.png":{diffuse_map: "broadcast_array_display.png", emission_map: broadcastDisplayEmissionPng}}
					);
					// Can't pass galaxy number to shader so hack to pass it via 'fuel' instead... this will allow
					// the broadcast arrays scrolling display in dock to 'change channel' to appropriate galaxy
					broadcastArray.fuel = galaxyNumber / 10;
					navbuoy.displayName = (tca.broadcastArrayName[galaxyNumber] + " Navigation Buoy");
					var navbuoyPng = (tca.broadcastChannel[galaxyNumber] + "_beacon.png");
					navbuoy.setMaterials({"broadcast_array_beacon.png": { diffuse_map: navbuoyPng }});

				},
				coordinates:arraypos,
				deterministic:true
			});
		}		
	}
}

this.shipWillLaunchFromStation = function(station) {
	if(station.hasRole("broadcast_array")) {
		missionVariables.trumbles = missionVariables.broadcastArray_storeTrumble; 
		// reactivate offer of trumble mission if it was available before docking
		missionVariables.broadcastArray_storeTrumble = null;
	}
}

this.shipWillDockWithStation = function(station) {
	if(station.hasRole("broadcast_array")) {
		// delay offer of trumble mission whilst docked at a broadcast array
		missionVariables.broadcastArray_storeTrumble = missionVariables.trumbles;
		missionVariables.trumbles = null;
	} 
}
